@@ -38,6 +38,11 @@
 
 #include "captionvalues.h"
 
+namespace KExiv2Iface
+{
+    class MsgTextEdit;
+}
+
 namespace Digikam
 {
 
@@ -58,6 +63,8 @@ public:
 
     void reset();
 
+    KExiv2Iface::MsgTextEdit* textEdit() const;
+
 Q_SIGNALS:
 
     void signalModified();
