@@ -113,8 +113,8 @@ extern "C"
 #include "loadingcacheinterface.h"
 #include "metadatasettings.h"
 #include "savingcontext.h"
-#include "setup.h"
-#include "setupmisc.h"
+#include "showfotosetup.h"
+#include "showfotosetupmisc.h"
 #include "setupicc.h"
 #include "slideshow.h"
 #include "splashscreen.h"
