@@ -7,7 +7,7 @@
  * Description : a parser for the AdvancedRename utility used for importing images,
  *               excluding the database options
  *
- * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at googlemail dot com>
+ * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -35,16 +35,13 @@ ImportRenameParser::ImportRenameParser()
     : Parser()
 {
     // unregister options that are not suitable during import
-    OptionsList oplist = options();
+    RulesList oplist = options();
 
-    foreach(Option* option, oplist)
+    foreach(Rule* option, oplist)
     {
-        Option* toBeRemoved = 0;
-        toBeRemoved = dynamic_cast<DatabaseOption*>(option);
-
-        if (toBeRemoved)
+        if (dynamic_cast<DatabaseOption*>(option))
         {
-            unregisterOption(toBeRemoved);
+            unregisterOption(option);
         }
     }
 }
