@@ -536,16 +536,7 @@ void Setup::okClicked()
 
     kapp->restoreOverrideCursor();
 
-    if (d->albumViewPage->useLargeThumbsAsChanged())
-    {
-        QString msg = i18n("The maximum thumbnail size has been changed.\n"
-                           "You need to restart digiKam to see this option to take effect.\n\n"
-                           "Note: after restarting digiKam, it is recommended to rebuild all "
-                           "album items' thumbnails, using the \"Tools-Maintenance\" menu.");
-        KMessageBox::information(this, msg);
-    }
-
-    if (d->metadataPage->exifAutoRotateAsChanged())
+    if (d->metadataPage->exifAutoRotateHasChanged())
     {
         QString msg = i18n("The Exif auto-rotate thumbnails option has been changed.\n"
                            "Do you want to rebuild all albums' items' thumbnails now?\n\n"
