@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2008-12-26
  * Description : a kipi plugin to import/export images to Facebook web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -29,17 +29,13 @@
 
 #include <QList>
 
-// KDE includes
-
-#include <kdialog.h>
-
 // LibKIPI includes
 
 #include <libkipi/interface.h>
 
-// LibKExiv2 includes
+// Local includes
 
-#include <libkexiv2/kexiv2.h>
+#include "kptooldialog.h"
 
 class QCloseEvent;
 
@@ -55,6 +51,9 @@ namespace KIPIPlugins
     class KPAboutData;
 }
 
+using namespace KIPI;
+using namespace KIPIPlugins;
+
 namespace KIPIFacebookPlugin
 {
 
@@ -65,14 +64,13 @@ class FbUser;
 class FbAlbum;
 class FbPhoto;
 
-class FbWindow : public KDialog
+class FbWindow : public KPToolDialog
 {
     Q_OBJECT
 
 public:
 
-    FbWindow(KIPI::Interface* interface, const QString& tmpFolder,
-             bool import, QWidget* parent);
+    FbWindow(const QString& tmpFolder, bool import, QWidget* const parent);
     ~FbWindow();
 
     /**
@@ -101,10 +99,10 @@ private Q_SLOTS:
     void slotUserChangeRequest();
     void slotReloadAlbumsRequest(long long userID);
     void slotNewAlbumRequest();
-    void slotHelp();
     void slotStartTransfer();
     void slotImageListChanged();
     void slotButtonClicked(int button);
+    void slotStopAndCloseProgressBar();
 
 private:
 
@@ -126,29 +124,26 @@ private:
 
 private:
 
-    bool                      m_import;
-    unsigned int              m_imagesCount;
-    unsigned int              m_imagesTotal;
-    QString                   m_tmpDir;
-    QString                   m_tmpPath;
+    bool         m_import;
+    unsigned int m_imagesCount;
+    unsigned int m_imagesTotal;
+    QString      m_tmpDir;
+    QString      m_tmpPath;
+
+    QString      m_profileAID;
+    QString      m_currentAlbumID;
 
-    QString                   m_profileAID;
-    QString                   m_currentAlbumID;
     // the next two entries are only used to upgrade to the new authentication scheme
-    QString                   m_sessionKey;             // old world session key
-    QString                   m_sessionSecret;          // old world session secret
-    unsigned int              m_sessionExpires;
-    QString                   m_accessToken;            // OAuth access token
+    QString      m_sessionKey;             // old world session key
+    QString      m_sessionSecret;          // old world session secret
+    unsigned int m_sessionExpires;
+    QString      m_accessToken;            // OAuth access token
 
-    KUrl::List                m_transferQueue;
+    KUrl::List   m_transferQueue;
 
-    FbTalker*                 m_talker;
-    FbWidget*                 m_widget;
-    FbNewAlbum*               m_albumDlg;
-
-    KIPI::Interface*          m_interface;
-
-    KIPIPlugins::KPAboutData* m_about;
+    FbTalker*    m_talker;
+    FbWidget*    m_widget;
+    FbNewAlbum*  m_albumDlg;
 };
 
 } // namespace KIPIFacebookPlugin
