@@ -7,9 +7,9 @@
  * @date   2006-09-19
  * @brief  Track file loading and managing
  *
- * @author Copyright (C) 2006-2013 by Gilles Caulier
+ * @author Copyright (C) 2006-2014 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2010, 2014 by Michael G. Hansen
+ * @author Copyright (C) 2010-2014 by Michael G. Hansen
  *         <a href="mailto:mike at mghansen dot de">mike at mghansen dot de</a>
  *
  * This program is free software; you can redistribute it
@@ -66,22 +66,22 @@ public:
         nextTrackColor(0),
         visibility(true)
     {
-
     }
 
     QFutureWatcher<TrackReader::TrackReadResult>* trackLoadFutureWatcher;
-    QFuture<TrackReader::TrackReadResult> trackLoadFuture;
-    TrackManager::Track::List trackPendingList;
-    TrackManager::Track::List trackList;
-    QList<QPair<KUrl, QString> > loadErrorFiles;
+    QFuture<TrackReader::TrackReadResult>         trackLoadFuture;
+    TrackManager::Track::List                     trackPendingList;
+    TrackManager::Track::List                     trackList;
+    QList<QPair<KUrl, QString> >                  loadErrorFiles;
 
-    Id   nextTrackId;
-    int  nextTrackColor;
-    bool visibility;
+    Id                                            nextTrackId;
+    int                                           nextTrackColor;
+    bool                                          visibility;
 };
 
 TrackManager::TrackManager(QObject* const parent)
-    : QObject(parent), d(new Private())
+    : QObject(parent),
+      d(new Private)
 {
 }
 
@@ -96,7 +96,7 @@ bool TrackManager::getVisibility() const
 
 void TrackManager::setVisibility(const bool value)
 {
-    if (d->visibility==value)
+    if (d->visibility == value)
     {
         return;
     }
